@@ -15,6 +15,5 @@ SYMBOLS = {
     'book_right': re.compile('([》])'),
     'comma': re.compile('([,，])'),
     'end_symbols': re.compile('([?\!…;？！。；])'),
-    'en_dot': re.compile('\.'),
-    'special_symbols': re.compile('([~～])')
+    'en_dot': re.compile('\.')
 }
